==> office-ui-fabric-react-0.49.0.tgz: package/lib-amd/demo/pages/DatePickerPage/DatePickerPage.js <==
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", 'react', '../../../index', '../../components/index', './examples/DatePicker.Basic.Example', './examples/DatePicker.Required.Example', './examples/DatePicker.Input.Example', '../../utilities/pageroute', '../../components/App/AppState'], function (require, exports, React, index_1, index_2, DatePicker_Basic_Example_1, DatePicker_Required_Example_1, DatePicker_Input_Example_1, pageroute_1, AppState_1) {
    "use strict";
    var DatePickerBasicExampleCode = require('./examples/DatePicker.Basic.Example.tsx');
    var DatePickerRequiredExampleCode = require('./examples/DatePicker.Required.Example.tsx');
    var DatePickerInputExampleCode = require('./examples/DatePicker.Input.Example.tsx');
    var DatePickerPage = (function (_super) {
        __extends(DatePickerPage, _super);
        function DatePickerPage() {
            _super.call(this);
            this._url = pageroute_1.getPageRouteFromState(AppState_1.AppState, 'Basic components', 'DatePicker');
        }
        DatePickerPage.prototype.render = function () {
            return (React.createElement(index_2.ComponentPage, {title: 'DatePicker', componentName: 'DatePickerExample', exampleCards: [
                React.createElement(index_2.ExampleCard, {title: 'DatePicker', code: DatePickerBasicExampleCode}, React.createElement(DatePicker_Basic_Example_1.DatePickerBasicExample, null)),
                React.createElement(index_2.ExampleCard, {title: 'DatePicker as required field', code: DatePickerRequiredExampleCode}, React.createElement(DatePicker_Required_Example_1.DatePickerRequiredExample, null)),
                React.createElement(index_2.ExampleCard, {title: 'DatePicker allows input date string', code: DatePickerInputExampleCode}, React.createElement(DatePicker_Input_Example_1.DatePickerInputExample, null))
            ], propertiesTables: [
                React.createElement(index_2.PropertiesTableSet, {componentName: 'DatePicker'})
            ], overview: React.createElement("div", null, React.createElement(index_1.Link, {target: '_blank', href: 'http://dev.office.com/fabric/components/datepicker'}, "DatePickers"), React.createElement("span", null, " provide a menu for use in context menus and dropdowns.")), route: this._url}));
        };
        return DatePickerPage;
    }(React.Component));
    exports.DatePickerPage = DatePickerPage;
});

==> office-ui-fabric-react-0.52.2.tgz: package/lib-amd/demo/pages/DatePickerPage/DatePickerPage.js <==
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", 'react', '../../../index', '../../components/index', './examples/DatePicker.Basic.Example', './examples/DatePicker.Required.Example', './examples/DatePicker.Input.Example', '../../utilities/pageroute', '../../components/App/AppState'], function (require, exports, React, index_1, index_2, DatePicker_Basic_Example_1, DatePicker_Required_Example_1, DatePicker_Input_Example_1, pageroute_1, AppState_1) {
    "use strict";
    var DatePickerBasicExampleCode = require('./examples/DatePicker.Basic.Example.tsx');
    var DatePickerRequiredExampleCode = require('./examples/DatePicker.Required.Example.tsx');
    var DatePickerInputExampleCode = require('./examples/DatePicker.Input.Example.tsx');
    var DatePickerPage = (function (_super) {
        __extends(DatePickerPage, _super);
        function DatePickerPage() {
            _super.call(this);
            this._url = pageroute_1.getPageRouteFromState(AppState_1.AppState, 'Basic components', 'DatePicker');
        }
        DatePickerPage.prototype.render = function () {
            return (React.createElement(index_2.ComponentPage, {title: 'DatePicker', componentName: 'DatePickerExample', exampleCards: [
                React.createElement(index_2.ExampleCard, {title: 'DatePicker', code: DatePickerBasicExampleCode}, React.createElement(DatePicker_Basic_Example_1.DatePickerBasicExample, null)),
                React.createElement(index_2.ExampleCard, {title: 'DatePicker as required field', code: DatePickerRequiredExampleCode}, React.createElement(DatePicker_Required_Example_1.DatePickerRequiredExample, null)),
                React.createElement(index_2.ExampleCard, {title: 'DatePicker allows input date string', code: DatePickerInputExampleCode}, React.createElement(DatePicker_Input_Example_1.DatePickerInputExample, null))
            ], propertiesTables: [
                React.createElement(index_2.PropertiesTableSet, {componentName: 'DatePicker'})
            ], overview: React.createElement("div", null, React.createElement(index_1.Link, {target: '_blank', href: 'http://dev.office.com/fabric/components/datepicker'}, "DatePickers"), React.createElement("span", null, " provide a menu for use in context menus and dropdowns.")), route: this._url, isHeaderVisible: this.props.isHeaderVisible}));
        };
        return DatePickerPage;
    }(React.Component));
    exports.DatePickerPage = DatePickerPage;
});
